@@ -114,7 +114,7 @@ class Listpg:
     
     async def remove(self, **opt):
         one_column = f"{list(opt.keys())[0]} = array_remove({list(opt.keys())[0]}, $1)"
-        enums = enumerate(opt.keys(), 2)
-        columns = ' AND '.join(f'{c} = ${i}' for i, c in enums)
+        enums = enumerate(opt.keys(), 1)
+        columns = ' AND '.join(f'{c} = ${i}' for i, c in enums if i != 1)
 
         await self.pool.execute(f'UPDATE {self.table} SET {one_column} WHERE {columns}', *opt.values())
\ No newline at end of file
